==> hs-split-0.2.1.1p0.tgz: lib/ghc/split-0.2.1.1/register.sh <==
#!/bin/sh
echo 'name: split
version: 0.2.1.1
id: split-0.2.1.1-d0476313c57b84b6637b0d5a6dc092dc

license: BSD3
copyright: (c) Brent Yorgey, Louis Wasserman 2008-2012
maintainer: byorgey@cis.upenn.edu
stability: stable
homepage:
package-url:
synopsis: Combinator library for splitting lists.
description: A collection of various methods for splitting
             lists into parts, akin to the \"split\" function
             found in several mainstream languages. Here is
             its tale:
             .
             Once upon a time the standard "Data.List" module
             held no function for splitting a list into parts
             according to a delimiter.  Many a brave
             lambda-knight strove to add such a function, but
             their striving was in vain, for Lo, the Supreme
             Council fell to bickering amongst themselves what
             was to be the essential nature of the One True
             Function which could cleave a list in twain (or
             thrain, or any required number of parts).
             .
             And thus came to pass the split package,
             comprising divers functions for splitting a list
             asunder, each according to its nature.  And the
             Supreme Council had no longer any grounds for
             argument, for the favored method of each was
             contained therein.
             .
             To get started, see the "Data.List.Split" module.
category: List
author: Brent Yorgey
pkgpath: devel/hs-split
exposed: True
exposed-modules: Data.List.Split Data.List.Split.Internals
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/split-0.2.1.1
library-dirs: /usr/local/lib/ghc/split-0.2.1.1
hs-libraries: HSsplit-0.2.1.1
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-split-0.2.1.1/html/split.haddock
haddock-html: /usr/local/share/doc/hs-split-0.2.1.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-split-0.2.2p0.tgz: lib/ghc/split-0.2.2/register.sh <==
#!/bin/sh
export PATH='/usr/obj/ports/hs-split-0.2.2/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
echo 'name: split
version: 0.2.2
id: split-0.2.2-00b34ebfe0428fa7ea316c4515f6481b

license: BSD3
copyright: (c) Brent Yorgey, Louis Wasserman 2008-2012
maintainer: byorgey@cis.upenn.edu
stability: stable
homepage:
package-url:
synopsis: Combinator library for splitting lists.
description: A collection of various methods for splitting
             lists into parts, akin to the \"split\" function
             found in several mainstream languages. Here is
             its tale:
             .
             Once upon a time the standard "Data.List" module
             held no function for splitting a list into parts
             according to a delimiter.  Many a brave
             lambda-knight strove to add such a function, but
             their striving was in vain, for Lo, the Supreme
             Council fell to bickering amongst themselves what
             was to be the essential nature of the One True
             Function which could cleave a list in twain (or
             thrain, or any required number of parts).
             .
             And thus came to pass the split package,
             comprising divers functions for splitting a list
             asunder, each according to its nature.  And the
             Supreme Council had no longer any grounds for
             argument, for the favored method of each was
             contained therein.
             .
             To get started, see the "Data.List.Split" module.
category: List
author: Brent Yorgey
pkgpath: devel/hs-split
exposed: True
exposed-modules: Data.List.Split Data.List.Split.Internals
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/split-0.2.2
library-dirs: /usr/local/lib/ghc/split-0.2.2
hs-libraries: HSsplit-0.2.2
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.7.0.2-b11c3b9ddc2bebe1a3d85499c9ea3f18
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-split-0.2.2/html/split.haddock
haddock-html: /usr/local/share/doc/hs-split-0.2.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
